From: Josef Sipek <jsipek@fsl.cs.sunysb.edu>

Signed-off-by: Josef Sipek <jsipek@fsl.cs.sunysb.edu>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/md/bitmap.c    |    8 ++++----
 drivers/md/dm-linear.c |    2 +-
 drivers/md/dm-mpath.c  |    2 +-
 drivers/md/md.c        |    4 ++--
 4 files changed, 8 insertions(+), 8 deletions(-)

diff -puN drivers/md/bitmap.c~struct-path-convert-md drivers/md/bitmap.c
--- a/drivers/md/bitmap.c~struct-path-convert-md
+++ a/drivers/md/bitmap.c
@@ -212,8 +212,8 @@ char *file_path(struct file *file, char 
 	if (!buf)
 		return NULL;
 
-	d = file->f_dentry;
-	v = file->f_vfsmnt;
+	d = file->f_path.dentry;
+	v = file->f_path.mnt;
 
 	buf = d_path(d, v, buf, count);
 
@@ -349,7 +349,7 @@ static struct page *read_page(struct fil
 			      unsigned long count)
 {
 	struct page *page = NULL;
-	struct inode *inode = file->f_dentry->d_inode;
+	struct inode *inode = file->f_path.dentry->d_inode;
 	struct buffer_head *bh;
 	sector_t block;
 
@@ -662,7 +662,7 @@ static void bitmap_file_put(struct bitma
 	bitmap_file_unmap(bitmap);
 
 	if (file) {
-		struct inode *inode = file->f_dentry->d_inode;
+		struct inode *inode = file->f_path.dentry->d_inode;
 		invalidate_inode_pages(inode->i_mapping);
 		fput(file);
 	}
diff -puN drivers/md/dm-linear.c~struct-path-convert-md drivers/md/dm-linear.c
--- a/drivers/md/dm-linear.c~struct-path-convert-md
+++ a/drivers/md/dm-linear.c
@@ -108,7 +108,7 @@ static int linear_ioctl(struct dm_target
 	struct dentry fake_dentry = {};
 
 	fake_file.f_mode = lc->dev->mode;
-	fake_file.f_dentry = &fake_dentry;
+	fake_file.f_path.dentry = &fake_dentry;
 	fake_dentry.d_inode = bdev->bd_inode;
 
 	return blkdev_driver_ioctl(bdev->bd_inode, &fake_file, bdev->bd_disk, cmd, arg);
diff -puN drivers/md/dm-mpath.c~struct-path-convert-md drivers/md/dm-mpath.c
--- a/drivers/md/dm-mpath.c~struct-path-convert-md
+++ a/drivers/md/dm-mpath.c
@@ -1270,7 +1270,7 @@ static int multipath_ioctl(struct dm_tar
 	struct dentry fake_dentry = {};
 	int r = 0;
 
-	fake_file.f_dentry = &fake_dentry;
+	fake_file.f_path.dentry = &fake_dentry;
 
 	spin_lock_irqsave(&m->lock, flags);
 
diff -puN drivers/md/md.c~struct-path-convert-md drivers/md/md.c
--- a/drivers/md/md.c~struct-path-convert-md
+++ a/drivers/md/md.c
@@ -4845,8 +4845,8 @@ static int md_seq_show(struct seq_file *
 				chunk_kb ? "KB" : "B");
 			if (bitmap->file) {
 				seq_printf(seq, ", file: ");
-				seq_path(seq, bitmap->file->f_vfsmnt,
-					 bitmap->file->f_dentry," \t\n");
+				seq_path(seq, bitmap->file->f_path.mnt,
+					 bitmap->file->f_path.dentry," \t\n");
 			}
 
 			seq_printf(seq, "\n");
_
